@@ -17,7 +17,7 @@ use Path::Class;
 use File::chdir;
 use Contextual::Return;
 
-our $VERSION = version->new('0.1.1');
+our $VERSION = version->new('0.2.0');
 our $name    = 'Bazaar';
 our $exe     = 'bzr';
 our $meta    = '.bzr';
@@ -86,7 +86,7 @@ sub pull {
 	croak "'$dir' is not a directory!" if !-e $dir;
 
 	local $CWD = $dir;
-	return !system "$exe pull";
+	return !system "$exe pull > /dev/null 2> /dev/null";
 }
 
 sub cat {
@@ -148,7 +148,7 @@ VCS::Which::Plugin::Bazaar - The Bazaar plugin for VCS::Which
 
 =head1 VERSION
 
-This documentation refers to VCS::Which::Plugin::Bazaar version 0.1.1.
+This documentation refers to VCS::Which::Plugin::Bazaar version 0.2.0.
 
 =head1 SYNOPSIS
 
